package es.caib.signatura.client.applet;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import es.caib.signatura.impl.util.SigDebug;
/**
 * Apend significa que no cierra el outputStream
 * Write significa que sí lo cierra
 * @author u91940
 *
 */
public class IOUtils {
	
	public static void streamAppendCopy( OutputStream output,InputStream input, int sizeBuffer) throws IOException {
		try {
			final byte[] buffer = new byte[sizeBuffer];
	        int n = 0;
	        while (-1 != (n = input.read(buffer))) {
	            output.write(buffer, 0, n);
	        }
		}finally{
			if(input!=null){
				try{
					input.close();
				}catch(IOException e){}
			}
		}
    }

	public static long streamWriteCopy( OutputStream output,InputStream input, int sizeBuffer) throws IOException {
		long counter=0;
		
		try {
			final byte[] buffer = new byte[sizeBuffer];
	        int n = 0;
	        while (-1 != (n = input.read(buffer))) {
	            counter+=n;
	        	output.write(buffer, 0, n);
	        }
		}finally{
			if(output!=null){
				try{
					output.close();
				}catch(IOException e){}
			}
			if(input!=null){
				try{
					input.close();
				}catch(IOException e){}
			}
		}
		return counter;
    }
	
	public static void writeFile(String outFilePath, InputStream inputStream) throws IOException{
		FileOutputStream out=null;
		try {
			out = new FileOutputStream(outFilePath);
		
			appendStream(out, inputStream);
				
		} catch (FileNotFoundException e) {
			SigDebug.error(e);
			throw e;
		} catch (IOException e) {
			SigDebug.error(e);
			throw e;
		}finally{
			if(out!=null){
				try{
					out.close();
				}catch(IOException e){}
			}
			if(inputStream!=null){
				try{
					inputStream.close();
				}catch(IOException e){}
			}
		}
		
	}
	public static void appendStream(OutputStream out, InputStream inputStream) throws IOException{
		try {
			byte b[]=new byte[10240];
			int readed=0;
			while((readed=inputStream.read(b))!=-1){
				out.write(b, 0, readed);
			}
		} catch (FileNotFoundException e) {
			SigDebug.error(e);
			throw e;
		} catch (IOException e) {
			SigDebug.error(e);
			throw e;
		}finally{
			if(inputStream!=null){
				try{
					inputStream.close();
				}catch(IOException e){}
			}
		}
		
	}	
	
	
	public static void writeBytes(OutputStream out, byte [] in) throws IOException{
		try {
			
			out.write(in);
		} catch (IOException e) {
			SigDebug.error(e);
			throw e;
		}finally{
			if(out!=null){
				try{
					out.close();
				}catch(IOException e){}
			}
		}
		
	}
	
	public static void appendBytes(OutputStream out, byte [] in) throws IOException{
		try {
			
			out.write(in);
		} catch (IOException e) {
			SigDebug.error(e);
			throw e;
		}finally{

		}
		
	}
	
	public static void copyFile(File in, File out) throws IOException {
		FileInputStream fis=new FileInputStream(in);
		FileOutputStream fos=new FileOutputStream(out);
		IOUtils.streamWriteCopy(fos, fis, 2048);
	}

	public static void deleteDirectoryRecursive(File temp) throws IOException {
		if(temp.isDirectory()){
			File[] files=temp.listFiles();
			for(int i=0;i<files.length;i++){
				if(files[i].isDirectory()) {
					deleteDirectoryRecursive(files[i]);
				}
				else files[i].delete();
			}
			temp.delete();
		}else{
			throw new IOException(temp+" is not a directory.");
		}
		
	}

	public static byte[] readStream(InputStream inputStream) throws IOException {
		ByteArrayOutputStream out=new ByteArrayOutputStream();
		byte[] outB;
		try {
			byte b[]=new byte[10240];
			int readed=0;
			while((readed=inputStream.read(b))!=-1){
				out.write(b, 0, readed);
			}
			outB=out.toByteArray();
		} catch (IOException e) {
			SigDebug.error(e);
			throw e;
		}finally{
			if(inputStream!=null){
				try{
					inputStream.close();
				}catch(IOException e){}
			}
			if(out!=null){
				try{
					out.close();
				}catch(IOException e){}
			}
		}
		return outB;
	}

}
